@@ -13,13 +13,9 @@
 #import "ID3Tagger.h"
 #include <id3/tag.h>
 #include <id3/misc_support.h>
+#import "MP3Header.h"
 #import "WMATagger.h"
 #import "UnicodeWrapper.h"
-#import "MP3Length.h"
-// for stat
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
 
 @interface ID3Tagger (PrivateAPI)
 // NB these can't be delcared in ID3Tagger.h as would then include id3/tag.h in other files which causes errors
@@ -104,16 +100,16 @@
 		return [WMATagger readTrack:filename];
 	}
 	
-	struct stat sb;
 	// check file exists
-	if (stat([filename fileSystemRepresentation], &sb) == -1)
+	NSFileManager *fileManager = [[NSFileManager alloc] init];
+	// this is used below to get filesize
+	NSDictionary *fileAttributes = [fileManager fileAttributesAtPath:filename traverseLink:YES];
+	if (fileAttributes == nil)
 		return nil;
 	
-	// N.B. cannot use NSFileManager as this is not thread safe
-		
 	Track *track = [[Track alloc] init];
-	
-	[track setFilesize:sb.st_size];
+		
+	[track setFilesize:[[fileAttributes objectForKey:NSFileSize] intValue]];
 	[track setCodec:[self codec]];
 	[track setFullPath:filename];
 	
@@ -142,7 +138,6 @@
 			if ([genre characterAtIndex:0] == 40)
 			{
 				NSRange bracketPos = [genre rangeOfCharacterFromSet:[NSCharacterSet characterSetWithCharactersInString:@")"]];
-				
 				if (bracketPos.length == 1 && bracketPos.location == [genre length] - 1)
 				{
 					NSRange numberRange;
@@ -164,7 +159,13 @@
 		[track setYear:[self intFrameContentsFromTag:&myTag frameID:ID3FID_YEAR]];
 		
 		// read the length from the header
-		[track setLength:[MP3Length length:filename]];
+		MP3Header *header = [[MP3Header alloc] init];
+		[track setLength:[header length:filename]];
+		[header release];
+		
+		// why can't I use id3lib like this? always returns NULL
+		/*const Mp3_Headerinfo *header = myTag.GetMp3HeaderInfo();
+		[track setLength:header->time];*/
 		
 		myTag.Clear();
 	
@@ -177,6 +178,7 @@
 		[track setLength:[self wavFileLength:filename]];
 	}
 	
+	[fileManager release];
 	return [track autorelease];
 }
 
@@ -210,15 +212,7 @@
 			ID3_Field *field = frame->GetField(ID3FN_TEXT);
 			if (field != NULL)
 			{
-				const char *rawText = field->GetRawText();
-				NSData *data = nil;
-				if (field->Size() == 0)
-					return [NSString stringWithString:@""];
-				if (rawText[field->Size() - 1] == 0)
-					// ignore the NULL terminator
-					data = [NSData dataWithBytes:field->GetRawText() length:(field->Size() - 1)];
-				else
-					data = [NSData dataWithBytes:field->GetRawText() length:field->Size()];
+				NSData *data = [NSData dataWithBytes:field->GetRawText() length:field->Size()];
 				NSString *asciiString = [[NSString alloc] initWithData:data encoding:NSISOLatin1StringEncoding];
 				return [asciiString autorelease];
 			}
