@@ -60,11 +60,6 @@
 	return settingsTab;
 }
 
-- (DuplicateItemsTab *)duplicateItemsTab
-{
-	return duplicateItemsTab;
-}
-
 /**********************/
 
 - (void)awakeFromNib
@@ -94,11 +89,6 @@
 	}
 	
 	[status setMainThreadQueueLock:myQueueLock];
-	
-	NSNotificationCenter *nc;
-	nc = [NSNotificationCenter defaultCenter];
-	[nc addObserver:self selector:@selector(NJBConnected:) name:NOTIFICATION_CONNECTED object:nil];
-	[nc addObserver:self selector:@selector(NJBDisconnected:) name:NOTIFICATION_DISCONNECTED object:nil];
 }
 
 - (void)tabView:(NSTabView *)tabView didSelectTabViewItem:(NSTabViewItem *)tabViewItem
@@ -116,8 +106,6 @@
 	int tabIndex = [tabViewMain indexOfTabViewItem:[tabViewMain selectedTabViewItem]];
 	if (tabIndex == TAB_MUSIC)
 		[musicTab drawerWriteTag:modifiedTrack];
-	else if (tabIndex == TAB_DUPLICATES)
-		[duplicateItemsTab drawerWriteTag:modifiedTrack];
 }
 
 - (void)onFirstResponderChange:(NSResponder *)aResponder
@@ -178,15 +166,17 @@
 	[queueTab setNJBQueueConsumer:njbQueue];
 	[dataTab setNJBQueueConsumer:njbQueue];
 	[playlistsTab setNJBQueueConsumer:njbQueue];
-	[duplicateItemsTab setNJBQueueConsumer:njbQueue];
 	[settingsTab setNJBQueueConsumer:njbQueue];
 }
 
 - (NSApplicationTerminateReply)applicationShouldTerminate:(NSApplication *)sender
 {
-	if (![self shouldClose])
+	if (![status isIdle])
 	{
-		return NSTerminateCancel;
+		int result = NSRunAlertPanel(@"Quit XNJB", @"There are still items in the queue.  Are you sure you want to quit?  This could crash your NJB and/or XNJB.",
+																 @"No", @"Yes", nil);
+		if (result == NSAlertDefaultReturn)
+			return NSTerminateCancel;
 	}
 	// do it in this thread as want to block
 	[theNJB disconnect];
@@ -198,18 +188,6 @@
 	return NSTerminateNow;
 }
 
-- (BOOL)shouldClose
-{
-	if (![status isIdle])
-	{
-		int result = NSRunAlertPanel(@"Quit XNJB", @"There are still items in the queue.  Are you sure you want to quit?  This could crash your NJB and/or XNJB.",
-																 @"No", @"Yes", nil);
-		if (result == NSAlertDefaultReturn)
-			return NO;
-	}
-	return YES;
-}
-
 - (id)currentTab
 {
 	return [self tabAtIndex:[tabViewMain indexOfTabViewItem:[tabViewMain selectedTabViewItem]]];
@@ -236,9 +214,6 @@
 		case TAB_SETTINGS:
 			return settingsTab;
 			break;
-		case TAB_DUPLICATES:
-			return duplicateItemsTab;
-			break;
 		case TAB_QUEUE:
 			return queueTab;
 			break;
@@ -264,9 +239,9 @@
 		if ([currentItem displayStatus])
 		{
 			if ([result class] == [NJBTransactionResult class])
-				[status taskComplete:result];
+				[status taskComplete:[result success]];
 			else
-				[status taskComplete:[[NJBTransactionResult alloc] initWithSuccess:YES]];
+				[status taskComplete:YES];
 		}
 	}
 	[myQueueLock unlock];
@@ -340,36 +315,4 @@
 	[self disconnectFromNJB];
 }
 
-- (IBAction)buttonConnect:(id)sender
-{
-	if (![theNJB isConnected])
-		[self connectToNJB];
-	else
-		[self disconnectFromNJB];
-}
-
-/* called when we disconnect
-*/
-- (void)NJBDisconnected:(NSNotification *)note
-{
-	[connectButton setTitle:@"Connect"];
-}
-
-/* called when we connect
-*/
-- (void)NJBConnected:(NSNotification *)note
-{
-	[connectButton setTitle:@"Disconnect"];
-}
-
-/* called when the main window is closing
- */
-- (BOOL)windowShouldClose:(id)sender
-{
-	[NSApp terminate:sender];
-	// don't close the window, because if we said don't close the app, we don't want the window closed but app still running
-	// if user asked to terminate app rather than just close window, windowShouldClose: is not called so we will close anyway
-	return NO;
-}
-
 @end
