@@ -40,6 +40,8 @@
 		
 		fileExtensionsToCodecsDictionary = [[NSDictionary alloc] initWithObjectsAndKeys:[NSNumber numberWithInt:CODEC_MP3],
 			@"mp3", [NSNumber numberWithInt:CODEC_WMA], @"wma", [NSNumber numberWithInt:CODEC_WAV], @"wav", nil];
+		
+		trackListIsUpToDate = NO;
 	}
 	return self;
 }
@@ -50,6 +52,13 @@
 	[super dealloc];
 }
 
+// accessor methods
+
+- (BOOL)trackListIsUpToDate
+{
+	return trackListIsUpToDate;
+}
+
 /**********************/
 
 - (void)awakeFromNib
@@ -66,16 +75,21 @@
 - (void)onConnectAndActive
 {
 	[super onConnectAndActive];
-	if ([playlistsTab fullItemArray])
+	if ([playlistsTab trackListIsUpToDate] && [playlistsTab fullItemArray])
 	{
 		// playlistsTab has already got it
 		[fullItemArray release];
 		fullItemArray = [[MyMutableArray alloc] initWithMyMutableArray:[playlistsTab fullItemArray]];
 		[self clearSortingArrows];
 		[self searchNJBTable];
+		
+		trackListIsUpToDate = YES;
 	}
 	else
+	{
 		[self loadTracks];
+		trackListIsUpToDate = YES;
+	}
 }
 
 - (SEL)sortSelectorForColumn:(NSString *)columnID
@@ -595,6 +609,8 @@
 	
 	if (isActive && activeObject == OBJECT_NJB_TABLE)
 		[drawerController disableWrite];
+	
+	trackListIsUpToDate = NO;
 }
 
 - (void)activate
