@@ -151,6 +151,8 @@ StatusDisplayer *statusDisplayerGlobal;
 - (NSString *)ownerString
 {
 	char *ownerString = NJB_Get_Owner_String (njb);
+	if (ownerString == NULL)
+		return nil;
 	NSString *nsOwnerString = [[NSString alloc] initWithUTF8String:ownerString];
 	free(ownerString);
 	return [nsOwnerString autorelease];
@@ -179,6 +181,8 @@ StatusDisplayer *statusDisplayerGlobal;
 		str = songid_label(songtag, FR_GENRE);
 		if (str != NULL)
 			[track setGenre:[NSString stringWithUTF8String:str]];
+		// this is not used: we don't get extended track info from njb3
+		// njb1 gets it but ignored
 		str = songid_label(songtag, FR_FNAME);
 		if (str != NULL)
 			[track setFilename:[NSString stringWithUTF8String:str]];
@@ -380,6 +384,8 @@ StatusDisplayer *statusDisplayerGlobal;
 - (NSCalendarDate *)jukeboxTime
 {
 	njb_time_t *time = NJB_Get_Time(njb);
+	if (time == NULL)
+		return nil;
 	
 	// assume njb time is our timezone
 	NSCalendarDate *date = [NSCalendarDate dateWithYear:time->year month:time->month day:time->day hour:time->hours minute:time->minutes second:time->seconds
