@@ -115,7 +115,7 @@
 	{
 		// create a new pool on each cycle
 		// so we don't end up with loads of autoreleased
-		// object when we get killed
+		// when we get killed
 		NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
 		
 		NSLog(@"Waiting for data...");
@@ -150,9 +150,9 @@
 			if ([njbQueueItem displayStatus])
 			{
 				if ([result class] == [NJBTransactionResult class])
-					[status taskComplete:result];
+					[status taskComplete:[result success]];
 				else
-					[status taskComplete:[[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease]];
+					[status taskComplete:YES];
 			}
 		}
 		
