@@ -60,34 +60,48 @@
 
 // init/dealloc methods
 
+- (id)init
+{
+	if (self = [super init])
+	{
+		trackListIsUpToDate = NO;
+	}
+	return self;
+}
+
 - (void)dealloc
 {
 	[playlists release];
 	[super dealloc];
 }
 
+// accessor methods
+
+- (BOOL)trackListIsUpToDate
+{
+	return trackListIsUpToDate;
+}
+
 /**********************/
 
 - (void)onConnectAndActive
 {
 	[super onConnectAndActive];
-	[self loadTracks];
-	[self loadPlaylists];
-}
-
-- (void)activate
-{
-	// this must be called first to run onConnectAndActive so we can download the tracks there
-	[super activate];
-	if (!trackListUpToDate)
+	if ([musicTab trackListIsUpToDate] && [musicTab fullItemArray])
 	{
+		// musicTab has already got it
 		[fullItemArray release];
-		fullItemArray = nil;
-		[truncatedItemArray release];
-		truncatedItemArray = nil;
-		[njbTable reloadData];
-		[self loadTracks];
+		fullItemArray = [[MyMutableArray alloc] initWithMyMutableArray:[musicTab fullItemArray]];
+		[self clearSortingArrows];
+		[self searchNJBTable];
+		trackListIsUpToDate = YES;
 	}
+	else
+	{
+		[self loadTracks];
+		trackListIsUpToDate = YES;
+	}
+	[self loadPlaylists];
 }
 
 - (void)awakeFromNib
@@ -250,8 +264,6 @@
 	[getTracks release];
 	[clearSortingArrows release];
 	[updateTable release];
-	// it's not actually yet, but will be in a while, don't want to go copying anything
-	trackListUpToDate = YES;
 }
 
 /* this is called from the queue consumer 
@@ -268,8 +280,6 @@
 	
 	[fullItemArray retain];
 	
-	trackListUpToDate = YES;
-	
 	return [result autorelease];
 }
 
@@ -485,6 +495,8 @@
 	[moveTracksUpButton setEnabled:NO];
 	[moveTracksDownButton setEnabled:NO];
 	[super NJBDisconnected:note];
+	
+	trackListIsUpToDate = NO;
 }
 
 - (void)tableView:(NSTableView *)aTableView setObjectValue:(id)anObject forTableColumn:(NSTableColumn *)aTableColumn row:(int)rowIndex
@@ -679,12 +691,4 @@
 	[playlistsTrackTable selectRow:(index + 1) byExtendingSelection:YES];
 }
 
-- (void)NJBTrackListModified:(NSNotification *)note
-{
-	if (!isActive)
-	{
-		trackListUpToDate = NO;
-	}
-}
-
 @end
