@@ -41,7 +41,18 @@
 {
 	if (self = [super init])
 	{
-		[self setValuesToTrack:track];
+		[self setTitle:[track title]];
+		[self setArtist:[track artist]];
+		[self setAlbum:[track album]];
+		[self setGenre:[track genre]];
+		[self setFilename:[track filename]];
+		[self setFullPath:[track fullPath]];
+		[self setTrackNumber:[track trackNumber]];
+		[self setYear:[track year]];
+		[self setFilesize:[track filesize]];
+		[self setLength:[track length]];
+		[self setCodec:[track codec]];
+		[self setTrackID:[track trackID]];
 	}
 	return self;
 }
@@ -65,10 +76,7 @@
 - (void)setTitle:(NSString *)newTitle
 {
 	if (newTitle == nil)
-	{
 		title = @"";
-		[title release];
-	}
 	else
 	{
 		// get immutable copy
@@ -86,10 +94,7 @@
 - (void)setAlbum:(NSString *)newAlbum
 {
 	if (newAlbum == nil)
-	{
-		[album release];
 		album = @"";
-	}
 	else
 	{
 		// get immutable copy
@@ -107,10 +112,7 @@
 - (void)setArtist:(NSString *)newArtist
 {
 	if (newArtist == nil)
-	{
-		[artist release];
 		artist = @"";
-	}
 	else
 	{
 		// get immutable copy
@@ -128,10 +130,7 @@
 - (void)setGenre:(NSString *)newGenre
 {
 	if (newGenre == nil)
-	{
-		[genre release];
 		genre = @"";
-	}
 	else
 	{
 		// get immutable copy
@@ -149,10 +148,7 @@
 - (void)setFilename:(NSString *)newFilename
 {
 	if (newFilename == nil)
-	{
-		[filename release];
 		filename = @"";
-	}
 	else
 	{
 		// get immutable copy
@@ -170,10 +166,7 @@
 - (void)setFullPath:(NSString *)newFullPath
 {
 	if (newFullPath == nil)
-	{
-		[fullPath release];
 		fullPath = @"";
-	}
 	else
 	{
 		// get immutable copy
@@ -293,22 +286,6 @@
 
 /**********************/
 
-- (void)setValuesToTrack:(Track *)track
-{
-	[self setTitle:[track title]];
-	[self setArtist:[track artist]];
-	[self setAlbum:[track album]];
-	[self setGenre:[track genre]];
-	[self setFilename:[track filename]];
-	[self setFullPath:[track fullPath]];
-	[self setTrackNumber:[track trackNumber]];
-	[self setYear:[track year]];
-	[self setFilesize:[track filesize]];
-	[self setLength:[track length]];
-	[self setCodec:[track codec]];
-	[self setTrackID:[track trackID]];
-}
-
 - (NSString *)description
 {
 	return [NSString stringWithFormat:@"Title: %@, Artist: %@, Album: %@, Genre: %@, Length: %@, Track No: %d, Codec: %@, Filesize: %@, Track ID: %d, Year: %d, Filename: %@, Fullpath: %@",
